==> api-0.8.2-sources.jar: eu/fispace/api/common/TextNotificationMessage.java <==
//
// Este archivo ha sido generado por la arquitectura JavaTM para la implantación de la referencia de enlace (JAXB) XML v2.2.7 
// Visite <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Todas las modificaciones realizadas en este archivo se perderán si se vuelve a compilar el esquema de origen. 
// Generado el: 2014.07.08 a las 03:34:38 PM CEST 
//


package eu.fispace.api.common;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * <p>Clase Java para anonymous complex type.
 * 
 * <p>El siguiente fragmento de esquema especifica el contenido que se espera que haya en esta clase.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="textNotification" type="{http://www.fispace.eu/domain/common}TextNotification"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "textNotification"
})
@XmlRootElement(name = "TextNotificationMessage")
public class TextNotificationMessage
    implements Serializable, ToString
{

    @XmlElement(required = true)
    protected TextNotification textNotification;

    /**
     * Obtiene el valor de la propiedad textNotification.
     * 
     * @return
     *     possible object is
     *     {@link TextNotification }
     *     
     */
    public TextNotification getTextNotification() {
        return textNotification;
    }

    /**
     * Define el valor de la propiedad textNotification.
     * 
     * @param value
     *     allowed object is
     *     {@link TextNotification }
     *     
     */
    public void setTextNotification(TextNotification value) {
        this.textNotification = value;
    }

    public boolean isSetTextNotification() {
        return (this.textNotification!= null);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        {
            TextNotification theTextNotification;
            theTextNotification = this.getTextNotification();
            strategy.appendField(locator, this, "textNotification", buffer, theTextNotification);
        }
        return buffer;
    }

    public TextNotificationMessage withTextNotification(TextNotification value) {
        setTextNotification(value);
        return this;
    }

}

==> api-0.9.0-sources.jar: eu/fispace/api/common/TextNotificationMessage.java <==
//
// Este archivo ha sido generado por la arquitectura JavaTM para la implantación de la referencia de enlace (JAXB) XML v2.2.7 
// Visite <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Todas las modificaciones realizadas en este archivo se perderán si se vuelve a compilar el esquema de origen. 
// Generado el: 2014.07.17 a las 08:57:14 AM CEST 
//


package eu.fispace.api.common;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * 
 * 					TODO: add explanation of this message type
 * 				
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "textNotification"
})
@XmlRootElement(name = "TextNotificationMessage")
public class TextNotificationMessage
    implements Serializable, ToString
{

    @XmlElement(required = true)
    protected TextNotification textNotification;

    /**
     * Obtiene el valor de la propiedad textNotification.
     * 
     * @return
     *     possible object is
     *     {@link TextNotification }
     *     
     */
    public TextNotification getTextNotification() {
        return textNotification;
    }

    /**
     * Define el valor de la propiedad textNotification.
     * 
     * @param value
     *     allowed object is
     *     {@link TextNotification }
     *     
     */
    public void setTextNotification(TextNotification value) {
        this.textNotification = value;
    }

    public boolean isSetTextNotification() {
        return (this.textNotification!= null);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        {
            TextNotification theTextNotification;
            theTextNotification = this.getTextNotification();
            strategy.appendField(locator, this, "textNotification", buffer, theTextNotification);
        }
        return buffer;
    }

    public TextNotificationMessage withTextNotification(TextNotification value) {
        setTextNotification(value);
        return this;
    }

}
